@@ -1,4 +1,4 @@
-package Pcore::Handle::redis;    ## no critic qw[NamingConventions::Capitalization]
+package Pcore::Handle::redis;
 
 use Pcore -class;
 use AnyEvent::RipeRedis;
